==> haskell-reflection-2.1.3-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.3
id: reflection-2.1.3-E897NHjR81y5st3IxFkElo
key: reflection-2.1.3-E897NHjR81y5st3IxFkElo
license: BSD3
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
exposed: True
indefinite: False
exposed-modules:
    Data.Reflection
abi: 87a75df00a5da86ca93e32495d8f2915
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/reflection-2.1.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/reflection-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/reflection-2.1.3
hs-libraries: HSreflection-2.1.3-E897NHjR81y5st3IxFkElo
depends:
    base-4.10.1.0 template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reflection-2.1.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-reflection.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.3
id: reflection-2.1.3-4SrNpWQSBW2LTCJ2jLk3f1
key: reflection-2.1.3-4SrNpWQSBW2LTCJ2jLk3f1
license: BSD-3-Clause
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
abi: f59bc1689e7c79247309d2cae266fd7b
exposed: True
exposed-modules:
    Data.Reflection
import-dirs: /usr/lib/ghc-8.4.3/site-local/reflection-2.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/reflection-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/reflection-2.1.3
hs-libraries: HSreflection-2.1.3-4SrNpWQSBW2LTCJ2jLk3f1
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
